library(ape)
library(kmer)
library(shipunov)

our <- read.table("40_concatenated/semistrict_orig.txt", sep="\t", h=T, as.is=T)

our.rt <- our[!is.na(our$its) & !is.na(our$rbcl), c("SP", "ID", "its", "rbcl", "trnl")]
rt <- apply(our.rt[, c("its", "rbcl")], 1, function(.x) paste(.x, collapse=""))
names(rt) <- apply(our.rt[, c("SP", "ID")], 1, function(.x) paste(.x, collapse="__"))
rt.dna <- as.DNAbin(as.alignment(as.list(rt)))

rt.dnadist <- dist.dna(rt.dna)
rt.kmer <- kdistance(rt.dna)
rt.dnadistm <- as.matrix(rt.dnadist)
rt.kmerm <- as.matrix(rt.kmer)
rt.dd <- (scale(rt.kmerm, center=F) + scale(rt.dnadistm, center=F)) / 2 # ;)

trnl.na <- names(rt)[is.na(our.rt$trnl)]
trnl.na1 <- do.call(rbind, strsplit(trnl.na, "__"))[, 1]
trnl.na <- trnl.na[!grepl("Nothotalisia", trnl.na1)] # do not impute Nothotalisia because it is imputed with Picramnia

trnl.subdd <- apply(rt.dd[, trnl.na], 2, function(.x) names(.x[.x > 0 & !is.na(our.rt$trnl)])[which.min(.x[.x > 0 & !is.na(our.rt$trnl)])])

ournames <- apply(our[, c("SP", "ID")], 1, function(.x) paste(.x, collapse="__"))
oi <- our
oi[match(names(trnl.subdd), ournames), "trnl"] <- our[match(trnl.subdd, ournames), "trnl"]
oi[match(names(trnl.subdd), ournames), "trnl.ID"] <- paste0(our[match(trnl.subdd, ournames), "ID"], "i")
cat("Imputed:\n")
data.frame(trnl.subdd)
cat("NOT imputed:\n")
data.frame(ournames[is.na(oi$trnl)])

## make joint ids
fragments <- c("its", "rbcl", "trnl") # fragile
our.f <- fragments[1:3] # fragile
our.f.ids <- paste0(our.f, ".ID")
ids.tmp1 <- apply(oi[, c("SP", "ID")], 1, function(.x) paste(.x, collapse="__"))
for (i in our.f.ids) oi[, i] <- ifelse(is.na(oi[, i]), "", paste(sub(".ID", "", i), oi[, i]))
ids.tmp2 <- apply(oi[, our.f.ids], 1, function(.x) paste(.x, collapse=" "))
ids.tmp2 <- gsub("(^ +)|( +$)", "", ids.tmp2)
ids.tmp2 <- gsub("( +)", " ", ids.tmp2)
ids.tmp <- paste(ids.tmp1, ids.tmp2)
ids.tmp <- gsub(" +", "_", ids.tmp)
ids.tmp <- gsub(",", "", ids.tmp)
ids.tmp <- gsub("_$", "", ids.tmp)
ids.tmp <- gsub("_NA_", "_", ids.tmp)

## replace NA's with N's and write resulted FASTA
for (i in our.f) oi[, i] <- ifelse(is.na(oi[, i]), paste(rep("N", max(nchar(oi[, i]), na.rm=T)), collapse=""), oi[, i])
seq.tmp <- apply(oi[, our.f], 1, function(.x) paste(.x, collapse=""))
oi2 <- data.frame(ID=ids.tmp, SEQ=seq.tmp, stringsAsFactors=F)
Write.fasta(oi2, file=paste0("40_concatenated/", "semistrict.fasta")) # replaces the original one!
