library(ape)
library(kmer)
library(shipunov)

DATE <- format(Sys.time(), "%Y%m%d_%H%M%S")

dna <- read.table("../../data/picramniaceae_dna.txt", h=T, sep="\t", as.is=T, quote="")

raw <- dna[dna$SEQUENCE.ID != "HQ664568", ] # remove "empty"
raw$ids.tmp <- apply(raw[, c("FRAGMENT", "SPECIES.NEW", "SEQUENCE.ID", "SELECT")], 1, function(.x) (paste(.x, collapse="_")))
Write.fasta(raw[, c("ids.tmp", "SEQUENCE")], file="40_concatenated/raw.fasta")
raw <- read.dna("40_concatenated/raw.fasta", format="fasta")
cat("raw kmer...\n")
raw.tree <- nj(kdistance(raw, k=7))
raw.tree$edge.length[raw.tree$edge.length < 0] <- 0.00001 # found experimentally
raw.tree$edge.length <- (raw.tree$edge.length + 0.005) * 2 # found experimentally

pdf(paste("50_technical_trees/", DATE, "_raw_kmer_nj_picramniaceae.pdf", sep=""), width=12, height=24)
oldpar <- par(mar=c(0,0,0,0))
plot(raw.tree, no.margin=T)
mtext("k-mer: raw, all", font=2, line=-3)
par(oldpar)
dev.off()

rawd <- dna[dna$SELECT == 1, ] # remove deselected
rawd$ids.tmp <- apply(rawd[, c("FRAGMENT", "SPECIES.NEW", "SEQUENCE.ID", "SELECT")], 1, function(.x) (paste(.x, collapse="_")))
Write.fasta(rawd[, c("ids.tmp", "SEQUENCE")], file="40_concatenated/rawd.fasta")
rawd <- read.dna("40_concatenated/rawd.fasta", format="fasta")
cat("rawd kmer...\n")
rawd.tree <- nj(kdistance(rawd, k=7))
rawd.tree$edge.length[rawd.tree$edge.length < 0] <- 0.00001 # found experimentally
rawd.tree$edge.length <- (rawd.tree$edge.length + 0.005) * 2 # found experimentally

pdf(paste("50_technical_trees/", DATE, "_rawd_kmer_nj_picramniaceae.pdf", sep=""), width=12, height=24)
oldpar <- par(mar=c(0,0,0,0))
plot(rawd.tree, no.margin=T)
mtext("k-mer: raw, deselected", font=2, line=-3)
par(oldpar)
dev.off()
