library(ape)
library(kmer)
DATE <- format(Sys.time(), "%Y%m%d_%H%M%S")
treesp <- read.table("../../data/picramniaceae_treesp.txt", sep="\t", h=T, as.is=T)
outgroups <- treesp$SPECIES.NEW[treesp$TYPE == "outgroup" & treesp$USE == 1]
outgroups <- gsub(" ", "_", outgroups)

outliers <- treesp$SPECIES.NEW[treesp$TYPE == "outlier"]
outliers <- gsub(" ", "_", outliers)

kmer <- read.dna("40_concatenated/semistrict.fasta", format="fasta")

LAB <- sub("__.*$", "", labels(kmer))
OUT <- labels(kmer)[LAB %in% outgroups]
EXC <- labels(kmer)[LAB %in% outliers] # is not used

cat("semistrict kmer...\n")
kmer.tree <- root(nj(kdistance(kmer, k=9)), OUT, resolve.root=T)
kmer.tree$edge.length[kmer.tree$edge.length < 0] <- 0.00001 # found experimentally

##
pdf(paste("50_technical_trees/", DATE, "_semistrict_kmer_nj_picramniaceae.pdf", sep=""), width=12, height=24)
oldpar <- par(mar=c(0,0,0,0))
plot(kmer.tree)
mtext("k-mer: whole data", font=2, line=-3)
par(oldpar)
dev.off()
##
